@@ -24,7 +24,7 @@
 /// @file main.cpp
 
 #include "parleymainwindow.h"
-#include "version.h"
+#include "config-parley.h"
 
 #include <KAboutData>
 #include <KCrash>
@@ -144,4 +144,4 @@ int main(int argc, char* argv[])
         parleyApp->show();
         return app.exec();
     }
-}
+}
\ No newline at end of file
